@@ -16,7 +16,7 @@ from urllib3.util.retry import Retry
 from tqdm import tqdm
 import ntpath
 
-__version__ = "1.2.3"
+__version__ = "1.2.4"
 CONFIG_PATH = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                            ".canvassyncer.json")
 MAX_DOWNLOAD_COUNT = 8
@@ -175,6 +175,19 @@ class CanvasSyncer:
                 requests.exceptions.ConnectionError) as e:
             raise ConnectionError(e)
 
+    def sessHead(self, *args, **kwargs):
+        if kwargs.get('timeout') is None:
+            kwargs['timeout'] = 10
+        if kwargs.get('header') is None:
+            kwargs['headers'] = dict()
+        kwargs['headers']['Authorization'] = f"Bearer {self.config['token']}"
+        kwargs['proxies'] = self.config.get("proxies")
+        try:
+            return self.sess.head(*args, **kwargs)
+        except (urllib3.exceptions.MaxRetryError,
+                requests.exceptions.ConnectionError) as e:
+            raise ConnectionError(e)
+
     def createFolders(self, courseID, folders):
         for folder in folders.values():
             path = os.path.join(self.downloadDir,
@@ -278,7 +291,7 @@ class CanvasSyncer:
                 localCreatedTimeStamp = int(os.path.getctime(path))
                 if fileModifiedTimeStamp <= localCreatedTimeStamp:
                     continue
-                response = self.sess.head(fileUrl)
+                response = self.sessHead(fileUrl)
                 fileSize = int(response.headers.get('content-length', 0))
                 self.laterDownloadSize += fileSize
                 self.laterFiles.append((fileUrl, path))
@@ -286,7 +299,7 @@ class CanvasSyncer:
                     f"{self.courseCode[courseID]}{fileName} ({round(fileSize / 2**20, 2)}MB)"
                 )
                 continue
-            response = self.sess.head(fileUrl)
+            response = self.sessHead(fileUrl)
             fileSize = int(response.headers.get('content-length', 0))
             if fileSize / 2**20 > self.config['filesizeThresh']:
                 if not self.confirmAll:
@@ -463,7 +476,7 @@ def run():
                 return
         config = json.load(open(configPath, 'r', encoding='UTF-8'))
         config['y'] = args.y
-        if args.proxy: config['proxies'] = args.proxy
+        config['proxies'] = args.proxy
         Syncer = CanvasSyncer(config)
         Syncer.sync()
     except ConnectionError as e:
@@ -473,7 +486,6 @@ def run():
         print(
             f"\nUnexpected Error: {e.__class__.__name__}. Please check your network and your token!"
         )
-        raise e
     except KeyboardInterrupt as e:
         if Syncer:
             Syncer.downloader.stop()
